/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: $ */

package org.apache.fop.config;

import java.io.File;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.fop.apps.FOPException;
import org.apache.fop.apps.FOUserAgent;
import org.apache.fop.render.pdf.BasePDFTestCase;

/**
 * Basic runtime test for FOP's font configuration. It is used to verify that 
 * nothing obvious is broken after compiling.
 */
public abstract class BaseUserConfigTestCase extends BasePDFTestCase {
    
    /** logging instance */
    protected Log log = LogFactory.getLog(BaseUserConfigTestCase.class);

    /**
     * @see junit.framework.TestCase#TestCase(String)
     */
    public BaseUserConfigTestCase(String name) {
        super(name);
    }

    protected void init() {
        // do nothing
    }

    /**
     * Test using a standard FOP font
     * @throws Exception checkstyle wants a comment here, even a silly one
     */
    public void testUserConfig() throws Exception {
        try {
            final File uc = getUserConfigFile();
            fopFactory.setUserConfig(uc);        
            final File baseDir = getBaseDir();
            final String fontFOFilePath = getFontFOFilePath();
            File foFile = new File(baseDir, fontFOFilePath);
            final boolean dumpOutput = false;
            FOUserAgent foUserAgent = fopFactory.newFOUserAgent();
            convertFO(foFile, foUserAgent, dumpOutput);
            fail( getName() + ": Expected Configuration Exception" );
        } catch (FOPException e) {
            // this *should* happen!
        } catch (Exception e) {
            fail( getName() + ": Expected FOPException but got: " + e.getMessage() );
        }
    }

    /** get test FOP config File */
    private String getFontFOFilePath() {
        return "test/xml/bugtests/font.fo";
    }

    /** get test FOP config File */
    abstract protected File getUserConfigFile();
}